@@ -1,37 +1,19 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012 GRNET S.A. All rights reserved.
+# Copyright (C) 2011-2014 GRNET S.A.
 #
-# Redistribution and use in source and binary forms, with or
-# without modification, are permitted provided that the following
-# conditions are met:
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-#   1. Redistributions of source code must retain the above
-#      copyright notice, this list of conditions and the following
-#      disclaimer.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#   2. Redistributions in binary form must reproduce the above
-#      copyright notice, this list of conditions and the following
-#      disclaimer in the documentation and/or other materials
-#      provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
-# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
-# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
-# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
-# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-# POSSIBILITY OF SUCH DAMAGE.
-#
-# The views and conclusions contained in the software and
-# documentation are those of the authors and should not be
-# interpreted as representing official policies, either expressed
-# or implied, of GRNET S.A.
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """This modules provides the interface for working with the ./kamaki library.
 The library is used to upload images to and register them with a Synnefo
@@ -87,7 +69,7 @@ class Kamaki(object):
 
     @staticmethod
     def get_cloud_by_name(name):
-        """Returns a dict with cloud info"""
+        """Returns a dictionary with cloud info"""
         return config.get('cloud', name)
 
     @staticmethod
@@ -104,7 +86,7 @@ class Kamaki(object):
 
     @staticmethod
     def remove_cloud(name):
-        """Deletes an existing cloud from the Kamaki configuration file"""
+        """Deletes an existing cloud from the ./Kamaki configuration file"""
         config.remove_option('cloud', name)
         config.write()
 
@@ -149,7 +131,7 @@ class Kamaki(object):
             self.account.token)
 
     def upload(self, file_obj, size=None, remote_path=None, hp=None, up=None):
-        """Upload a file to pithos"""
+        """Upload a file to Pithos+"""
 
         path = basename(file_obj.name) if remote_path is None else remote_path
 
@@ -168,7 +150,7 @@ class Kamaki(object):
                                       self.CONTAINER, path)
 
     def register(self, name, location, metadata, public=False):
-        """Register an image with cyclades"""
+        """Register an image with Cyclades"""
 
         # Convert all metadata to strings
         str_metadata = {}
@@ -184,7 +166,7 @@ class Kamaki(object):
         self.pithos.set_object_sharing(location, "*")
 
     def object_exists(self, location):
-        """Check if an object exists in pythos"""
+        """Check if an object exists in Pithos+"""
 
         try:
             self.pithos.get_object_info(location)
